#!/usr/bin/env node
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const clean_up_agents_1 = require("../lib/core/commands/clean-up-agents");
const record_output_1 = require("../lib/core/commands/record-output");
const start_ci_run_1 = require("../lib/core/commands/start-ci-run");
const stop_all_agents_1 = require("../lib/core/commands/stop-all-agents");
const distributed_agent_impl_1 = require("../lib/core/runners/distributed-agent/distributed-agent.impl");
const upload_and_show_run_details_1 = require("../lib/core/commands/upload-and-show-run-details");
const update_manager_1 = require("../lib/light-client/update-manager");
const path_1 = require("path");
const stripJsonComments = require("strip-json-comments");
const fs_1 = require("fs");
const debug_logger_1 = require("../lib/light-client/debug-logger");
const command = process.argv[2];
const options = JSON.parse(stripJsonComments((0, fs_1.readFileSync)(`nx.json`).toString())).tasksRunnerOptions.default.options;
if (options.useLightClient) {
    Promise.resolve().then(() => __awaiter(void 0, void 0, void 0, function* () { return invokeCommandWithLightRunner(options); }));
}
else {
    invokeCommandFromBundledImplementation();
}
function invokeCommandWithLightRunner(options) {
    return __awaiter(this, void 0, void 0, function* () {
        (0, debug_logger_1.debugLog)('Verifying current cloud bundle');
        const { version, fullPath } = yield (0, update_manager_1.verifyOrUpdateCloudBundle)(options);
        (0, debug_logger_1.debugLog)('Done: ', fullPath);
        const runner = require((0, path_1.join)(process.cwd(), fullPath, 'index.js'));
        if (command === 'start-agent') {
            runner.startAgent().catch((e) => {
                console.error(e);
                process.exit(1);
            });
        }
        else if (command === 'stop-all-agents') {
            runner.stopAllAgents().catch((e) => {
                console.error(e);
                process.exit(1);
            });
        }
        else if (command === 'start-ci-run') {
            runner.startCiRun().catch((e) => {
                console.error(e);
                process.exit(1);
            });
        }
        else if (command === 'clean-up-agents') {
            runner.cleanUpAgents().catch((e) => {
                console.error(e);
                process.exit(1);
            });
        }
        else if (command === 'record') {
            runner.runCommandAndStoreInCloud().catch((e) => {
                console.error(e);
                process.exit(1);
            });
        }
        else if (command === 'upload-and-show-run-details') {
            runner.uploadAndShowRunDetails().catch((e) => {
                console.error(e);
                process.exit(1);
            });
        }
        else {
            console.log('Pass start-agent, stop-all-agents, or clean-up-agents');
        }
    });
}
function invokeCommandFromBundledImplementation() {
    if (command === 'start-agent') {
        (0, distributed_agent_impl_1.startAgent)().catch((e) => {
            console.error(e);
            process.exit(1);
        });
    }
    else if (command === 'stop-all-agents') {
        (0, stop_all_agents_1.stopAllAgents)().catch((e) => {
            console.error(e);
            process.exit(1);
        });
    }
    else if (command === 'start-ci-run') {
        (0, start_ci_run_1.startCiRun)().catch((e) => {
            console.error(e);
            process.exit(1);
        });
    }
    else if (command === 'clean-up-agents') {
        (0, clean_up_agents_1.cleanUpAgents)().catch((e) => {
            console.error(e);
            process.exit(1);
        });
    }
    else if (command === 'record') {
        (0, record_output_1.runCommandAndStoreInCloud)().catch((e) => {
            console.error(e);
            process.exit(1);
        });
    }
    else if (command === 'upload-and-show-run-details') {
        (0, upload_and_show_run_details_1.uploadAndShowRunDetails)().catch((e) => {
            console.error(e);
            process.exit(1);
        });
    }
    else {
        console.log('Pass start-agent, stop-all-agents, or clean-up-agents');
    }
}
//# sourceMappingURL=nx-cloud.js.map